@@ -10,7 +10,9 @@ DEVICE_TYPE_PURE_COOL_2021 = "438E"  # Not sure about the official name
 DEVICE_TYPE_PURE_COOL_DESK = "520"
 DEVICE_TYPE_PURE_HUMIDIFY_COOL = "358"
 DEVICE_TYPE_PURE_HOT_COOL_LINK = "455"
+DEVICE_TYPE_PURE_HOT_COOL_LINK_NEW = "455A"
 DEVICE_TYPE_PURE_HOT_COOL = "527"
+DEVICE_TYPE_PURE_HOT_COOL_NEW = "527E"
 
 DEVICE_TYPE_NAMES = {
     DEVICE_TYPE_360_EYE: "360 Eye robot vacuum",
@@ -21,7 +23,9 @@ DEVICE_TYPE_NAMES = {
     DEVICE_TYPE_PURE_COOL_LINK: "Pure Cool Link",
     DEVICE_TYPE_PURE_COOL_LINK_DESK: "Pure Cool Link Desk",
     DEVICE_TYPE_PURE_HOT_COOL: "Pure Hot+Cool",
+    DEVICE_TYPE_PURE_HOT_COOL_NEW: "Pure Hot+Cool (New)",
     DEVICE_TYPE_PURE_HOT_COOL_LINK: "Pure Hot+Cool Link",
+    DEVICE_TYPE_PURE_HOT_COOL_LINK_NEW: "Pure Hot+Cool Link (New)",
     DEVICE_TYPE_PURE_HUMIDIFY_COOL: "Pure Humidify+Cool",
 }
 
